@@ -57,7 +57,7 @@ FUNCTION = Schema({
         "type": "function",
         "name": str,
         Optional("constant"): bool,
-        "payable": bool,
+        Optional("payable"): bool,
         "stateMutability": MUTABILITY,
         "inputs": [FUNC_PARAMETER],
         "outputs": [FUNC_PARAMETER]
